@@ -3,9 +3,13 @@ pub mod cli;
 pub mod input {
     mod formatter;
     mod iterator;
+    mod provider;
+    mod separator;
     mod source;
     pub use self::formatter::*;
     pub use self::iterator::*;
+    pub use self::provider::*;
+    pub use self::separator::*;
     pub use self::source::*;
 }
 
