@@ -1,10 +1,9 @@
 use assert_cmd::Command;
+use nomino::input::MAIN_SEPARATOR;
+use std::fs::File;
 use std::fs::create_dir_all;
 use std::fs::read_dir;
-use std::fs::File;
-use std::path::MAIN_SEPARATOR;
 
-#[cfg(not(target_os = "windows"))]
 #[test]
 fn test_default() {
     let dir = tempfile::tempdir().unwrap();
@@ -26,6 +25,7 @@ fn test_default() {
     let cmd = Command::cargo_bin(env!("CARGO_PKG_NAME"))
         .unwrap()
         .args(&[
+            "-E",
             "-d",
             dir.path().to_str().unwrap(),
             r".*E(\d+).*",
@@ -48,7 +48,6 @@ fn test_default() {
     dir.close().unwrap();
 }
 
-#[cfg(not(target_os = "windows"))]
 #[test]
 fn test_default_not_overwrite() {
     let dir = tempfile::tempdir().unwrap();
@@ -69,7 +68,13 @@ fn test_default_not_overwrite() {
 
     let cmd = Command::cargo_bin(env!("CARGO_PKG_NAME"))
         .unwrap()
-        .args(&["-d", dir.path().to_str().unwrap(), r".*E(\d+).*", "1.mkv"])
+        .args(&[
+            "-E",
+            "-d",
+            dir.path().to_str().unwrap(),
+            r".*E(\d+).*",
+            "1.mkv",
+        ])
         .unwrap();
 
     let mut files: Vec<String> = read_dir(dir.path())
@@ -87,7 +92,6 @@ fn test_default_not_overwrite() {
     dir.close().unwrap();
 }
 
-#[cfg(not(target_os = "windows"))]
 #[test]
 fn test_default_overwrite() {
     let dir = tempfile::tempdir().unwrap();
@@ -109,6 +113,7 @@ fn test_default_overwrite() {
     let cmd = Command::cargo_bin(env!("CARGO_PKG_NAME"))
         .unwrap()
         .args(&[
+            "-E",
             "-d",
             dir.path().to_str().unwrap(),
             "-w",
@@ -132,7 +137,6 @@ fn test_default_overwrite() {
     dir.close().unwrap();
 }
 
-#[cfg(not(target_os = "windows"))]
 #[test]
 fn test_default_subdir() {
     let dir = tempfile::tempdir().unwrap();
@@ -159,6 +163,7 @@ fn test_default_subdir() {
     let cmd = Command::cargo_bin(env!("CARGO_PKG_NAME"))
         .unwrap()
         .args(&[
+            "-E",
             "-d",
             dir.path().to_str().unwrap(),
             "-k",
@@ -191,7 +196,6 @@ fn test_default_subdir() {
     dir.close().unwrap();
 }
 
-#[cfg(not(target_os = "windows"))]
 #[test]
 fn test_default_subdir_depth() {
     let dir = tempfile::tempdir().unwrap();
@@ -218,6 +222,7 @@ fn test_default_subdir_depth() {
     let cmd = Command::cargo_bin(env!("CARGO_PKG_NAME"))
         .unwrap()
         .args(&[
+            "-E",
             "--depth",
             "2",
             "-d",
@@ -252,7 +257,6 @@ fn test_default_subdir_depth() {
     dir.close().unwrap();
 }
 
-#[cfg(not(target_os = "windows"))]
 #[test]
 fn test_default_subdir_max_depth() {
     let dir = tempfile::tempdir().unwrap();
@@ -279,6 +283,7 @@ fn test_default_subdir_max_depth() {
     let cmd = Command::cargo_bin(env!("CARGO_PKG_NAME"))
         .unwrap()
         .args(&[
+            "-E",
             "--depth",
             "3",
             "--max-depth",
@@ -315,7 +320,6 @@ fn test_default_subdir_max_depth() {
     dir.close().unwrap();
 }
 
-#[cfg(not(target_os = "windows"))]
 #[test]
 fn test_default_subdir_not_overwrite() {
     let dir = tempfile::tempdir().unwrap();
@@ -342,6 +346,7 @@ fn test_default_subdir_not_overwrite() {
     let cmd = Command::cargo_bin(env!("CARGO_PKG_NAME"))
         .unwrap()
         .args(&[
+            "-E",
             "-d",
             dir.path().to_str().unwrap(),
             "-k",
@@ -374,7 +379,6 @@ fn test_default_subdir_not_overwrite() {
     dir.close().unwrap();
 }
 
-#[cfg(not(target_os = "windows"))]
 #[test]
 fn test_default_subdir_overwrite() {
     let dir = tempfile::tempdir().unwrap();
@@ -401,6 +405,7 @@ fn test_default_subdir_overwrite() {
     let cmd = Command::cargo_bin(env!("CARGO_PKG_NAME"))
         .unwrap()
         .args(&[
+            "-E",
             "-d",
             dir.path().to_str().unwrap(),
             "-k",
