@@ -1,9 +1,8 @@
 use assert_cmd::Command;
-use std::fs::read_dir;
 use std::fs::File;
+use std::fs::read_dir;
 use std::io::Write;
 
-#[cfg(not(target_os = "windows"))]
 #[test]
 fn test_map() {
     let dir = tempfile::tempdir().unwrap();
@@ -51,6 +50,7 @@ fn test_map() {
     let cmd = Command::cargo_bin(env!("CARGO_PKG_NAME"))
         .unwrap()
         .args(&[
+            "-E",
             "-d",
             dir.path().to_str().unwrap(),
             "-m",
@@ -74,7 +74,7 @@ fn test_map() {
 
     let cmd_undo = Command::cargo_bin(env!("CARGO_PKG_NAME"))
         .unwrap()
-        .args(&["-d", dir.path().to_str().unwrap(), "-m", "undo.json"])
+        .args(&["-E", "-d", dir.path().to_str().unwrap(), "-m", "undo.json"])
         .unwrap();
 
     let mut files_undo: Vec<String> = read_dir(dir.path())
@@ -87,10 +87,12 @@ fn test_map() {
 
     assert!(cmd_undo.status.success());
     assert_eq!(files_undo.len(), outputs.len());
-    assert!(outputs_undo
-        .iter()
-        .zip(files_undo.iter())
-        .all(|(a, b)| a == b));
+    assert!(
+        outputs_undo
+            .iter()
+            .zip(files_undo.iter())
+            .all(|(a, b)| a == b)
+    );
 
     dir.close().unwrap();
 }
