@@ -1,8 +1,7 @@
 use assert_cmd::Command;
-use std::fs::read_dir;
 use std::fs::File;
+use std::fs::read_dir;
 
-#[cfg(not(target_os = "windows"))]
 #[test]
 fn test_sort() {
     let dir = tempfile::tempdir().unwrap();
@@ -23,7 +22,14 @@ fn test_sort() {
 
     let cmd = Command::cargo_bin(env!("CARGO_PKG_NAME"))
         .unwrap()
-        .args(&["-d", dir.path().to_str().unwrap(), "-s", "asc", "{:3}.mkv"])
+        .args(&[
+            "-E",
+            "-d",
+            dir.path().to_str().unwrap(),
+            "-s",
+            "asc",
+            "{:3}.mkv",
+        ])
         .unwrap();
 
     let mut files: Vec<String> = read_dir(dir.path())
